import numpy as np
import matplotlib.cm as cm
import matplotlib.pyplot as plt

DELTAX=0.1               # Spatial resolution
SYMX=51-1                # Center position, X
SYMY=51-1                # Center position, Y
filename='wind_2d.stat'  # Data file name

data = np.loadtxt(filename, skiprows=3, unpack=True)

ipoints = int(np.max(data[0])-np.min(data[0])+1)
jpoints = int(np.max(data[1])-np.min(data[1])+1)

ZS = data[4].reshape(ipoints, -1).transpose()   # Convert into maps
WM = data[5].reshape(ipoints, -1).transpose()
WUT = data[7].reshape(ipoints, -1).transpose()
WVT = data[8].reshape(ipoints, -1).transpose()

arrayI = np.arange(0, ipoints)*DELTAX   # Spatial scales
arrayJ = np.arange(0, jpoints)*DELTAX
maxI = np.max(arrayI)
maxJ = np.max(arrayJ)

im = plt.imshow(WM, interpolation='bilinear', origin='lower',  # Show image
                extent=[0, maxI, 0, maxJ], cmap=cm.hot_r)

cbar = plt.colorbar(im, orientation='vertical')
cbar.set_label("Wind speed (m/s)")

maxzs = np.max(ZS)
minzs = np.min(ZS)
levels = np.linspace(minzs, maxzs, 25)      # Set contour levels

plt.contour(arrayI,arrayJ,ZS,levels,colors='k',origin='lower',linewidths=0.5)

plt.plot([arrayI[SYMX]],[arrayJ[SYMY]],"o",color='black', ms=8)

plt.quiver(arrayI[::5],arrayJ[::5],WUT[::5,::5],WVT[::5,::5],   # Arrows
           headwidth=6,headlength=6)

plt.title("Wind speed - hour 007 or hour 000 MST")
plt.xlabel('Km')
plt.ylabel('Km')
plt.tight_layout()
plotfile = 'wind_speed.png'
plt.savefig(plotfile, dpi=200)
plt.show()
print("Created file:", plotfile)
