"""
Image calibration
"""
import os
from pipeline import RawPipeline, fits
from numpy import ma

DATADIR = "/dati-18.7.2017"

MIN_DARK = -35.0
MAX_DARK = 35.0
MIN_FLAT = 0.7
MAX_FLAT = 1.1

def calibrate(img, step, args, common_args):
    shortname = os.path.basename(args["filename"])
    print("--- Calibrating:", shortname, end=" ", flush=True)
    cal = (img-common_args["dark"])/common_args["flat"]
    calname = os.path.join("work", shortname.replace("fit", "cal"))
    cal.dump(calname)
    print("OK")
    
if __name__ == "__main__":
    dfile = os.path.join(DATADIR, "masterdark.fits")
    ffile = os.path.join(DATADIR, "masterflat.fits")
    dark = ma.masked_outside(fits.getdata(dfile), MIN_DARK, MAX_DARK)
    flat = ma.masked_outside(fits.getdata(ffile), MIN_FLAT, MAX_FLAT)
    pipe = RawPipeline(calibrate, {"dark":dark, "flat":flat})
    pipe.run()
