import json
import numpy as np
import matplotlib.pyplot as plt
from pipeline import CalPipeline
from photutils import CircularAperture, aperture_photometry
from show import show


CIRCFILE = "selected.dat"
STAR_RADIUS = 30
SHOW_APERTURES = True

class Recenter:
    def __init__(self, shifts):
        self.shifts = shifts

    def shift(self, step):
        return self.shifts[step]

def flux(img, ctd, ax):
    aperture = CircularAperture(ctd[0:2], STAR_RADIUS)
    flx = aperture_photometry(img, aperture)
    if ax:
        aperture.plot(ax=ax, color="cyan")
    return flx["aperture_sum"][0]
 
DIFF_FLUX = []
STAR_FLUXES=[]
def calc_flux(img, step, args, common_args):
    global DIFF_FLUX
    fluxes = []
    ax = common_args["axes"]
    shf = common_args["shifts"].shift(step)
    if ax:
        ax.cla()
        show(img)
    for cc in common_args["circles"]:
        ctd = [cc[0]+shf[0], cc[1]+shf[1], cc[2]]
        fluxes.append(flux(img, ctd, ax))
    STAR_FLUXES.append(fluxes)
    diff_flux = fluxes[0]/sum(fluxes[1:])
    DIFF_FLUX.append(diff_flux)
    print("Step %d done"%step)
    if ax:
        plt.pause(0.05)

if __name__ == "__main__":
    if SHOW_APERTURES:
        plt.ion()
        fig = plt.figure()
        ax = plt.gca()
    else:
        ax = None
    shifts = Recenter(np.load("shifts_cc.dat"))
    with open(CIRCFILE) as cfile:
        cdata = json.load(cfile)
    pipe = CalPipeline(calc_flux, {"circles": cdata, "shifts": shifts, "axes": ax})
    pipe.run()
